@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef _LIBCUDACXX___ALGORITHM_COPY_IF_H
-#define _LIBCUDACXX___ALGORITHM_COPY_IF_H
+#ifndef _CUDA_STD___ALGORITHM_COPY_IF_H
+#define _CUDA_STD___ALGORITHM_COPY_IF_H
 
 #include <cuda/std/detail/__config>
 
@@ -22,7 +22,7 @@
 
 #include <cuda/std/__cccl/prologue.h>
 
-_LIBCUDACXX_BEGIN_NAMESPACE_STD
+_CCCL_BEGIN_NAMESPACE_CUDA_STD
 
 _CCCL_EXEC_CHECK_DISABLE
 template <class _InputIterator, class _OutputIterator, class _Predicate>
@@ -40,8 +40,8 @@ copy_if(_InputIterator __first, _InputIterator __last, _OutputIterator __result,
   return __result;
 }
 
-_LIBCUDACXX_END_NAMESPACE_STD
+_CCCL_END_NAMESPACE_CUDA_STD
 
 #include <cuda/std/__cccl/epilogue.h>
 
-#endif // _LIBCUDACXX___ALGORITHM_COPY_IF_H
+#endif // _CUDA_STD___ALGORITHM_COPY_IF_H
